@@ -1,4 +1,4 @@
-# $Id: SQL.pm 42415 2014-10-21 11:10:07Z anton $
+# $Id: SQL.pm 42646 2014-12-02 15:49:50Z anton $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/pwdmodifier/libpwdmodifier/lib/UvT/PwdModifier/SQL.pm $
 #
 # Er wordt door deze app geschreven naar adb123, die wordt eens in het uur ofzo gelezen
@@ -85,9 +85,9 @@ sub new {
 	my $db = DBI->connect($self->dsn, $self->user, $self->pass, $dbi_options);
 
 	$self->{getAccount} = $db->prepare("SELECT anr, usernaam FROM adb413usernaam\@lnkpg WHERE anr = ? AND usnstat in ('A','E')");
-	$self->{getUsername} = $db->prepare("SELECT usernaam FROM adb413usernaam\@lnkpg WHERE anr = ? AND usnstat in ('A','E')");
+	$self->{getUsername} = $db->prepare(q{SELECT usernaam FROM adb413usernaam@lnkpg WHERE anr = ? AND usnstat in ('A','E')});
 
-	$self->{getAnr} = $db->prepare("SELECT anr FROM adb413usernaam\@lnkpg WHERE usernaam = lower(?) AND usnstat in ('A','E')");
+	$self->{getAnr} = $db->prepare("SELECT anr FROM adb413usernaam\@lnkpg WHERE lower(usernaam) = lower(?) AND usnstat in ('A','E')");
 	$self->{previousPasswords} = $db->prepare("SELECT pw_rcrypt_after FROM adb123\@lnkdea.kub.nl WHERE anr = ? ORDER BY change_time");
 	$self->{previousSHAPasswords} = $db->prepare("SELECT pw_sha_after FROM adb123\@lnkdea.kub.nl WHERE anr = ? ORDER BY change_time");
 	$self->{initialPassword} = $db->prepare("SELECT pwserv FROM adb113r\@lnkdea.kub.nl WHERE anr = ?");
